
*** EX21 - A JAVAMETA Map with User-Controlled Pop-Ups;
*** data from STATISTICS CANADA web site;

data canada_pop;
input
province        :  $2.
province_name & : $21.
(pop_2001 pop_1996 area_sqk) (: comma.)
;
pop_density = pop_2001 / area_sqk;
label
pop_2001    = 'POPULATION 2001'
pop_1996    = 'POPULATION 1996'
area_sqk    = 'AREA SQUARE KILOMETERS'
;
format pop_2001 pop_1996 area: comma10.;
datalines;
10 NEWFOUNDLAND             512,930	  551,792      370,502
11 PRINCE EDWARD ISLAND     135,294       134,557        5,684
12 NOVA SCOTIA              908,007       909,282       52,917
13 NEW BRUNSWICK            729,498       738,133       71,356
24 QUEBEC                 7,237,479     7,138,795    1,357,743
35 ONTARIO               11,410,046    10,753,573      907,656
46 MANITOBA               1,119,583     1,113,898      551,938
47 SASKATCHEWAN             978,933       990,237      586,561
48 ALBERTA                2,974,807     2,696,826      639,987
59 BRITISH COLUMBIA       3,907,738     3,724,500      926,492
60 YUKON                     28,674        30,766      474,707
61 NORTHWEST TERRITORIES     64,105        64,402    3,066,569
;
run;

data canada_pop;
length popvar $500;
set canada_pop;
pct = 100 * (pop_2001 - pop_1996) / pop_1996;
pop_density = pop_2001 / area_sqk;
popvar = 'tip=[' ||
         quote(province_name) || ' ' ||
         quote('POPULATION')  || ' ' ||
         quote('1996: '       || put(pop_1996,comma10.)) || ' ' ||
         quote('2001: '       || put(pop_2001,comma10.)) || ' ' ||
         quote('%CHANGE:  '   || put(pct,10.1))          || ' ' ||
         quote('POPULATION DENSITY')                     || ' ' ||
         quote('PER SQ KM: '  || put(pop_density,10.3))   || ']' ;

run;

*** reset graphics options to default values, select the JAVA device driver and map size;
goptions reset=all
device=javameta
xpixels=1024
ypixels=768
ftext='HelveticaBold'
;

*** choose a set of colors - sequentially increasing shades of blue;
pattern1 v=ms c=cxeff3ff;
pattern2 v=ms c=cxbdd7e7;
pattern3 v=ms c=cx6baed6;
pattern4 v=ms c=cx2171b5;

*** specify parameters for the legend;
legend1
origin=(70,60)pct
across=1
mode=share
label=(position=top j=l 'POPULATION PER SQ KM')
shape=bar(3,4)pct
;

ods results off;
ods listing close;
ods html path='z:\'
         body='canada_meta.html'
         parameters=("ZoomControlEnabled"="false"
                     "DataTipStyle"="Stick_Fixed");

title 'CANADIAN POPULATION DENSITY BY PROVINCE, 2001';
footnote j=r 'EX21.SAS';
proc gmap data=canada_pop map=maps.canada2;
id province;
choro pop_density / levels=4 coutline=blue legend=legend1 html=popvar;
format province $provname. pop_density 6.3;
label province = 'PROVINCE';
run;
quit;
title;

ods html close;
ods listing;
ods results;
