
*** EX22 - An Animated Map;

*** data from US CENSUS BUREAU web site;
*** create an annotate data set to place a marker on the map at the population ceter;
*** year, latitude/longitude of US population center, county/state of US population center;
data popctr;
retain
function 'label'
xsys
ysys     '2'
hsys     '3'
position '5'
size      4
color    'green'
style    'marker'
text     'V'
when     'a'
;
infile datalines dsd;
input year : $4. y x co : $40. st : $2.;
fips = stfips(st);
y = y*constant('pi')/180;
x = x*constant('pi')/180;
datalines;
1790,39.275,76.18667     ,KENT,MD
1800,39.26833,76.94167   ,HOWARD,MD
1810,39.19167,77.62      ,LOUDON,VA
1820,39.095,78.55        ,HARDY,WV
1830,38.965,79.28167     ,GRANT,WV
1840,39.03333,80.3       ,UPSHUR,WV
1850,38.98333,81.31667   ,WIRT,WV
1860,39.00667,82.81333   ,PIKE,OH
1870,39.2,83.595         ,HIGHLAND,OH
1880,39.06889,84.66111   ,BOONE,KY
1890,39.19889,85.54806   ,DECATUR,IN
1900,39.16,85.815        ,BARTHOLOMEW,IN
1910,39.17,86.53889      ,MONROE,IN
1920,39.1725,86.72083    ,OWEN,IN
1930,39.0625,87.135      ,GREENE,IN
1940,38.948333,87.37639  ,SULLIVAN,IN
1950,38.80417,88.36889   ,CLAY,IL
1960,38.59944,89.20972   ,CLINTON,IL
1970,38.46306,89.70611   ,ST CLAIR,IL
1980,38.13694,90.57389   ,JEFFERSON,MO
1990,37.87222,91.21528   ,CRAWFORD,MO
2000,37.69699,91.80957   ,PHELPS,MO
;
run;

*** combine observations for selected states from MAPS.STATES map data set with annotate data;
data both;
set
maps.states (where=(fipstate(state) in
                   ("IA" "IL" "IN" "OH" "PA" "MO" "KY" "WV" "VA"
                    "TN" "NC" "MD" "DE" "DC" "AR" "NJ" "NY")
                   and density le 3))
popctr;
run;
run;

*** project the unprojected latitude/longitude in data set BOTH;
proc gproject data=both out=bothproj;
id state;
run;

*** separate projected map coordinates from the projected annotate data coordinates;
data pmap pop;
set bothproj;
if when eq 'a' then output pop;
else                output pmap;
run;

*** reset all graphics options to default values, select the GIFANIM device driver;
*** specify other parameters for the GIF file including ITERATION and DELAY (animation controls);
goptions
reset=all
device=gifanim
gsfname=animout
gsfmode=replace
gunit=pct
ftext='Tahoma'
ctext=blue
border
iteration=0
delay=200
;

*** ;
pattern v=e c=blue;

%macro manymaps;
%do i=1 %to 22;

%if &i eq  2 %then goptions gsfmode=append;;
%if &i eq 22 %then goptions gepilog='3B'x;;

data anno;
length text $50;
set pop (obs=&i) end=last;
if last then do;
    color='red';
    call symput('year',year);
    call symput('cost',trim(co) || ' COUNTY, ' || st);
    call symput('fips',put(fips,z3.));
end;
run;

pattern v=s c=yellow;

title1 h=3;
title2 h=5 "CENTER OF US POPULATION:  &YEAR";
footnote1 h=3 "&cost";
footnote2 h=10;
proc gmap map=pmap data=pmap (where=(state=&fips)) all;
id state;
choro state / discrete nolegend coutline=blue cempty=blue annotate=anno;
run;
quit;
title;
footnote;
%end;
%mend;

filename animout 'z:\popctr.gif';
%manymaps;
